@@ -20,3 +20,6 @@ class Forcing(ABC):
         if not isinstance(interval, timedelta):
             interval = timedelta(seconds=interval)
         self.__interval = interval
+
+    def __eq__(self, other: 'Forcing') -> bool:
+        return self.__class__ == other.__class__ and self.__dict__ == other.__dict__
