@@ -1,10 +1,11 @@
 from collections import Mapping
-import logging
 import pathlib
 
 import numpy as np
 
-logger = logging.getLogger(__name__)
+from adcircpy.utilities import get_logger
+
+LOGGER = get_logger(__name__)
 
 
 class NodalAttributes:
@@ -188,7 +189,7 @@ class NodalAttributes:
             if attribute not in self._attributes:
                 self.add_attribute(attribute, data['units'])
             else:
-                logger.warning(f'overwriting existing attribute "{attribute}"')
+                LOGGER.warning(f'overwriting existing attribute "{attribute}"')
             self.set_attribute(attribute, full_values)
 
     def write(self, path, overwrite=False):
@@ -199,7 +200,7 @@ class NodalAttributes:
                 with open(path, 'w') as f:
                     f.write(str(self))
             else:
-                logger.warning(f'skipping existing file "{path}"')
+                LOGGER.warning(f'skipping existing file "{path}"')
         else:
             print(str(self))
 
